@@ -6,7 +6,10 @@ warnings.filterwarnings('ignore')
 # Try to import optional dependencies
 try:
     import matplotlib
-    matplotlib.use('qtagg')  # Set the backend before importing pyplot
+    try:
+        matplotlib.use('qtagg')  # Set the backend before importing pyplot
+    except ImportError:
+        matplotlib.use('Agg')  # Fall back to headless backend for CI/testing
     import matplotlib.pyplot as plt
     from matplotlib.figure import Figure
     from matplotlib.backends.backend_qtagg import FigureCanvasQTAgg
